cb_api_finance_expense_management_client library
Classes
- AuthorizeBankReply
- AuthorizeBankRequest
- AuthorizeFinancialInstitutionReply
- AuthorizeFinancialInstitutionReply_Bank
- AuthorizeFinancialInstitutionRequest
- ContributeToExpenseReply
- ContributeToExpenseRequest
- ContributeToExpensesReply
- ContributeToExpensesRequest
- ContributeToExpensesRequest_Contribution
- CreateExpenseReply
- CreateExpenseRequestV2
- CreateIncomeReply
- CreateIncomeRequest
- CreateScheduleRequest
- CreateScheduleRequest_Annually
- CreateScheduleRequest_Daily
- CreateScheduleRequest_MonthlyByDate
- CreateScheduleRequest_MonthlyByWeekday
- CreateScheduleRequest_WeekDaily
- CreateScheduleRequest_Weekly
- Date
- DeleteExpenseReply
- DeleteExpenseRequest
- DeleteIncomeReply
- DeleteIncomeRequest
- ExpenseCandidateReply
- ExpenseManagementClient
- ExpenseManagementServiceBase
- ExpensePaymentHistoryRecordReply
- ExpenseReplyV2
- GetBalanceReply
- GetBalanceReplyV2
- GetBalanceReplyV2_Bank
- GetBalanceReplyV2_FinancialInstitution
- GetBalanceReplyV2_UsedFor
- GetBalanceRequest
- GetBankTokenReply
- GetBankTokenRequest
- GetExpensePaymentHistoryReply
- GetExpensePaymentHistoryRequest
- GetExpensesReplyV2
- GetExpensesRequest
- GetFinancialInstitutionLinkTokenReply
- GetFinancialInstitutionLinkTokenRequest
- IncomeCandidateReply
- IncomeReply
- Interval
- RejectExpenseCandidateReply
- RejectExpenseCandidateRequest
- RejectIncomeCandidateReply
- RejectIncomeCandidateRequest
- ReorderExpensesReply
- ReorderExpensesRequest
- ReviewExpenseCandidatesReply
- ReviewExpenseCandidatesReply_AcceptedExpenseCandidateReply
- ReviewExpenseCandidatesRequest
- ReviewExpenseCandidatesRequest_AcceptExpenseCandidateRequest
- ScheduleReplyV2
- ScheduleReplyV2_Annually
- ScheduleReplyV2_Daily
- ScheduleReplyV2_MonthlyByDate
- ScheduleReplyV2_MonthlyByWeekday
- ScheduleReplyV2_WeekDaily
- ScheduleReplyV2_Weekly
- SuggestExpensesReply
- SuggestExpensesRequest
- Timestamp
- A Timestamp represents a point in time independent of any time zone or local calendar, encoded as a count of seconds and fractions of seconds at nanosecond resolution. The count is relative to an epoch at UTC midnight on January 1, 1970, in the proleptic Gregorian calendar which extends the Gregorian calendar backwards to year one.
- UnlinkBankReply
- UnlinkBankRequest
- UnlinkFinancialInstitutionReply
- UnlinkFinancialInstitutionRequest
- UpdateExpenseReply
- UpdateExpenseRequestV2
- UpdateFinancialInstitutionReply
- UpdateFinancialInstitutionRequest
- UpdateFinancialInstitutionRequest_Bank
- UpdateIncomeReply
- UpdateIncomeRequest
- Weekday
- WithdrawFromExpenseReply
- WithdrawFromExpenseRequest
Constants
-
AuthorizeBankReply$json
→ const Map<
String, Object> -
AuthorizeBankRequest$json
→ const Map<
String, Object> -
AuthorizeFinancialInstitutionReply$json
→ const Map<
String, Object> -
AuthorizeFinancialInstitutionReply_Bank$json
→ const Map<
String, Object> -
AuthorizeFinancialInstitutionRequest$json
→ const Map<
String, Object> -
ContributeToExpenseReply$json
→ const Map<
String, String> -
ContributeToExpenseRequest$json
→ const Map<
String, Object> -
ContributeToExpensesReply$json
→ const Map<
String, String> -
ContributeToExpensesRequest$json
→ const Map<
String, Object> -
ContributeToExpensesRequest_Contribution$json
→ const Map<
String, Object> -
CreateExpenseReply$json
→ const Map<
String, Object> -
CreateExpenseRequestV2$json
→ const Map<
String, Object> -
CreateIncomeReply$json
→ const Map<
String, Object> -
CreateIncomeRequest$json
→ const Map<
String, Object> -
CreateScheduleRequest$json
→ const Map<
String, Object> -
CreateScheduleRequest_Annually$json
→ const Map<
String, Object> -
CreateScheduleRequest_Daily$json
→ const Map<
String, String> -
CreateScheduleRequest_MonthlyByDate$json
→ const Map<
String, Object> -
CreateScheduleRequest_MonthlyByWeekday$json
→ const Map<
String, Object> -
CreateScheduleRequest_WeekDaily$json
→ const Map<
String, String> -
CreateScheduleRequest_Weekly$json
→ const Map<
String, Object> -
Date$json
→ const Map<
String, Object> -
DeleteExpenseReply$json
→ const Map<
String, String> -
DeleteExpenseRequest$json
→ const Map<
String, Object> -
DeleteIncomeReply$json
→ const Map<
String, String> -
DeleteIncomeRequest$json
→ const Map<
String, Object> -
ExpenseCandidateReply$json
→ const Map<
String, Object> -
ExpensePaymentHistoryRecordReply$json
→ const Map<
String, Object> -
ExpenseReplyV2$json
→ const Map<
String, Object> -
GetBalanceReply$json
→ const Map<
String, Object> -
GetBalanceReplyV2$json
→ const Map<
String, Object> -
GetBalanceReplyV2_Bank$json
→ const Map<
String, Object> -
GetBalanceReplyV2_FinancialInstitution$json
→ const Map<
String, Object> -
GetBalanceReplyV2_UsedFor$json
→ const Map<
String, Object> -
GetBalanceRequest$json
→ const Map<
String, String> -
GetBankTokenReply$json
→ const Map<
String, Object> -
GetBankTokenRequest$json
→ const Map<
String, Object> -
GetExpensePaymentHistoryReply$json
→ const Map<
String, Object> -
GetExpensePaymentHistoryRequest$json
→ const Map<
String, Object> -
GetExpensesReplyV2$json
→ const Map<
String, Object> -
GetExpensesRequest$json
→ const Map<
String, String> -
GetFinancialInstitutionLinkTokenReply$json
→ const Map<
String, Object> -
GetFinancialInstitutionLinkTokenRequest$json
→ const Map<
String, Object> -
IncomeCandidateReply$json
→ const Map<
String, Object> -
IncomeReply$json
→ const Map<
String, Object> -
Interval$json
→ const Map<
String, Object> -
RejectExpenseCandidateReply$json
→ const Map<
String, String> -
RejectExpenseCandidateRequest$json
→ const Map<
String, Object> -
RejectIncomeCandidateReply$json
→ const Map<
String, String> -
RejectIncomeCandidateRequest$json
→ const Map<
String, Object> -
ReorderExpensesReply$json
→ const Map<
String, String> -
ReorderExpensesRequest$json
→ const Map<
String, Object> -
ReviewExpenseCandidatesReply$json
→ const Map<
String, Object> -
ReviewExpenseCandidatesReply_AcceptedExpenseCandidateReply$json
→ const Map<
String, Object> -
ReviewExpenseCandidatesRequest$json
→ const Map<
String, Object> -
ReviewExpenseCandidatesRequest_AcceptExpenseCandidateRequest$json
→ const Map<
String, Object> -
ScheduleReplyV2$json
→ const Map<
String, Object> -
ScheduleReplyV2_Annually$json
→ const Map<
String, Object> -
ScheduleReplyV2_Daily$json
→ const Map<
String, String> -
ScheduleReplyV2_MonthlyByDate$json
→ const Map<
String, Object> -
ScheduleReplyV2_MonthlyByWeekday$json
→ const Map<
String, Object> -
ScheduleReplyV2_WeekDaily$json
→ const Map<
String, String> -
ScheduleReplyV2_Weekly$json
→ const Map<
String, Object> -
SuggestExpensesReply$json
→ const Map<
String, String> -
SuggestExpensesRequest$json
→ const Map<
String, String> -
UnlinkBankReply$json
→ const Map<
String, Object> -
UnlinkBankRequest$json
→ const Map<
String, Object> -
UnlinkFinancialInstitutionReply$json
→ const Map<
String, String> -
UnlinkFinancialInstitutionRequest$json
→ const Map<
String, Object> -
UpdateExpenseReply$json
→ const Map<
String, String> -
UpdateExpenseRequestV2$json
→ const Map<
String, Object> -
UpdateFinancialInstitutionReply$json
→ const Map<
String, String> -
UpdateFinancialInstitutionRequest$json
→ const Map<
String, Object> -
UpdateFinancialInstitutionRequest_Bank$json
→ const Map<
String, Object> -
UpdateIncomeReply$json
→ const Map<
String, String> -
UpdateIncomeRequest$json
→ const Map<
String, Object> -
Weekday$json
→ const Map<
String, Object> -
WithdrawFromExpenseReply$json
→ const Map<
String, String> -
WithdrawFromExpenseRequest$json
→ const Map<
String, Object>
Properties
-
Descriptor for
AuthorizeBankReply. Decode as agoogle.protobuf.DescriptorProto.final -
Descriptor for
AuthorizeBankRequest. Decode as agoogle.protobuf.DescriptorProto.final -
Descriptor for
AuthorizeFinancialInstitutionReply. Decode as agoogle.protobuf.DescriptorProto.final -
Descriptor for
AuthorizeFinancialInstitutionRequest. Decode as agoogle.protobuf.DescriptorProto.final - contributeToExpenseReplyDescriptor → Uint8List
-
Descriptor for
ContributeToExpenseReply. Decode as agoogle.protobuf.DescriptorProto.final - contributeToExpenseRequestDescriptor → Uint8List
-
Descriptor for
ContributeToExpenseRequest. Decode as agoogle.protobuf.DescriptorProto.final - contributeToExpensesReplyDescriptor → Uint8List
-
Descriptor for
ContributeToExpensesReply. Decode as agoogle.protobuf.DescriptorProto.final - contributeToExpensesRequestDescriptor → Uint8List
-
Descriptor for
ContributeToExpensesRequest. Decode as agoogle.protobuf.DescriptorProto.final - createExpenseReplyDescriptor → Uint8List
-
Descriptor for
CreateExpenseReply. Decode as agoogle.protobuf.DescriptorProto.final - createExpenseRequestV2Descriptor → Uint8List
-
Descriptor for
CreateExpenseRequestV2. Decode as agoogle.protobuf.DescriptorProto.final - createIncomeReplyDescriptor → Uint8List
-
Descriptor for
CreateIncomeReply. Decode as agoogle.protobuf.DescriptorProto.final - createIncomeRequestDescriptor → Uint8List
-
Descriptor for
CreateIncomeRequest. Decode as agoogle.protobuf.DescriptorProto.final - createScheduleRequestDescriptor → Uint8List
-
Descriptor for
CreateScheduleRequest. Decode as agoogle.protobuf.DescriptorProto.final - dateDescriptor → Uint8List
-
Descriptor for
Date. Decode as agoogle.protobuf.DescriptorProto.final - deleteExpenseReplyDescriptor → Uint8List
-
Descriptor for
DeleteExpenseReply. Decode as agoogle.protobuf.DescriptorProto.final - deleteExpenseRequestDescriptor → Uint8List
-
Descriptor for
DeleteExpenseRequest. Decode as agoogle.protobuf.DescriptorProto.final - deleteIncomeReplyDescriptor → Uint8List
-
Descriptor for
DeleteIncomeReply. Decode as agoogle.protobuf.DescriptorProto.final - deleteIncomeRequestDescriptor → Uint8List
-
Descriptor for
DeleteIncomeRequest. Decode as agoogle.protobuf.DescriptorProto.final - expenseCandidateReplyDescriptor → Uint8List
-
Descriptor for
ExpenseCandidateReply. Decode as agoogle.protobuf.DescriptorProto.final - expensePaymentHistoryRecordReplyDescriptor → Uint8List
-
Descriptor for
ExpensePaymentHistoryRecordReply. Decode as agoogle.protobuf.DescriptorProto.final - expenseReplyV2Descriptor → Uint8List
-
Descriptor for
ExpenseReplyV2. Decode as agoogle.protobuf.DescriptorProto.final - getBalanceReplyDescriptor → Uint8List
-
Descriptor for
GetBalanceReply. Decode as agoogle.protobuf.DescriptorProto.final - getBalanceReplyV2Descriptor → Uint8List
-
Descriptor for
GetBalanceReplyV2. Decode as agoogle.protobuf.DescriptorProto.final - getBalanceRequestDescriptor → Uint8List
-
Descriptor for
GetBalanceRequest. Decode as agoogle.protobuf.DescriptorProto.final - getBankTokenReplyDescriptor → Uint8List
-
Descriptor for
GetBankTokenReply. Decode as agoogle.protobuf.DescriptorProto.final - getBankTokenRequestDescriptor → Uint8List
-
Descriptor for
GetBankTokenRequest. Decode as agoogle.protobuf.DescriptorProto.final - getExpensePaymentHistoryReplyDescriptor → Uint8List
-
Descriptor for
GetExpensePaymentHistoryReply. Decode as agoogle.protobuf.DescriptorProto.final - getExpensePaymentHistoryRequestDescriptor → Uint8List
-
Descriptor for
GetExpensePaymentHistoryRequest. Decode as agoogle.protobuf.DescriptorProto.final - getExpensesReplyV2Descriptor → Uint8List
-
Descriptor for
GetExpensesReplyV2. Decode as agoogle.protobuf.DescriptorProto.final - getExpensesRequestDescriptor → Uint8List
-
Descriptor for
GetExpensesRequest. Decode as agoogle.protobuf.DescriptorProto.final - getFinancialInstitutionLinkTokenReplyDescriptor → Uint8List
-
Descriptor for
GetFinancialInstitutionLinkTokenReply. Decode as agoogle.protobuf.DescriptorProto.final - getFinancialInstitutionLinkTokenRequestDescriptor → Uint8List
-
Descriptor for
GetFinancialInstitutionLinkTokenRequest. Decode as agoogle.protobuf.DescriptorProto.final - incomeCandidateReplyDescriptor → Uint8List
-
Descriptor for
IncomeCandidateReply. Decode as agoogle.protobuf.DescriptorProto.final - incomeReplyDescriptor → Uint8List
-
Descriptor for
IncomeReply. Decode as agoogle.protobuf.DescriptorProto.final - intervalDescriptor → Uint8List
-
Descriptor for
Interval. Decode as agoogle.protobuf.EnumDescriptorProto.final - rejectExpenseCandidateReplyDescriptor → Uint8List
-
Descriptor for
RejectExpenseCandidateReply. Decode as agoogle.protobuf.DescriptorProto.final - rejectExpenseCandidateRequestDescriptor → Uint8List
-
Descriptor for
RejectExpenseCandidateRequest. Decode as agoogle.protobuf.DescriptorProto.final - rejectIncomeCandidateReplyDescriptor → Uint8List
-
Descriptor for
RejectIncomeCandidateReply. Decode as agoogle.protobuf.DescriptorProto.final - rejectIncomeCandidateRequestDescriptor → Uint8List
-
Descriptor for
RejectIncomeCandidateRequest. Decode as agoogle.protobuf.DescriptorProto.final - reorderExpensesReplyDescriptor → Uint8List
-
Descriptor for
ReorderExpensesReply. Decode as agoogle.protobuf.DescriptorProto.final - reorderExpensesRequestDescriptor → Uint8List
-
Descriptor for
ReorderExpensesRequest. Decode as agoogle.protobuf.DescriptorProto.final - reviewExpenseCandidatesReplyDescriptor → Uint8List
-
Descriptor for
ReviewExpenseCandidatesReply. Decode as agoogle.protobuf.DescriptorProto.final - reviewExpenseCandidatesRequestDescriptor → Uint8List
-
Descriptor for
ReviewExpenseCandidatesRequest. Decode as agoogle.protobuf.DescriptorProto.final - scheduleReplyV2Descriptor → Uint8List
-
Descriptor for
ScheduleReplyV2. Decode as agoogle.protobuf.DescriptorProto.final - suggestExpensesReplyDescriptor → Uint8List
-
Descriptor for
SuggestExpensesReply. Decode as agoogle.protobuf.DescriptorProto.final - suggestExpensesRequestDescriptor → Uint8List
-
Descriptor for
SuggestExpensesRequest. Decode as agoogle.protobuf.DescriptorProto.final - unlinkBankReplyDescriptor → Uint8List
-
Descriptor for
UnlinkBankReply. Decode as agoogle.protobuf.DescriptorProto.final - unlinkBankRequestDescriptor → Uint8List
-
Descriptor for
UnlinkBankRequest. Decode as agoogle.protobuf.DescriptorProto.final - unlinkFinancialInstitutionReplyDescriptor → Uint8List
-
Descriptor for
UnlinkFinancialInstitutionReply. Decode as agoogle.protobuf.DescriptorProto.final - unlinkFinancialInstitutionRequestDescriptor → Uint8List
-
Descriptor for
UnlinkFinancialInstitutionRequest. Decode as agoogle.protobuf.DescriptorProto.final - updateExpenseReplyDescriptor → Uint8List
-
Descriptor for
UpdateExpenseReply. Decode as agoogle.protobuf.DescriptorProto.final - updateExpenseRequestV2Descriptor → Uint8List
-
Descriptor for
UpdateExpenseRequestV2. Decode as agoogle.protobuf.DescriptorProto.final - updateFinancialInstitutionReplyDescriptor → Uint8List
-
Descriptor for
UpdateFinancialInstitutionReply. Decode as agoogle.protobuf.DescriptorProto.final - updateFinancialInstitutionRequestDescriptor → Uint8List
-
Descriptor for
UpdateFinancialInstitutionRequest. Decode as agoogle.protobuf.DescriptorProto.final - updateIncomeReplyDescriptor → Uint8List
-
Descriptor for
UpdateIncomeReply. Decode as agoogle.protobuf.DescriptorProto.final - updateIncomeRequestDescriptor → Uint8List
-
Descriptor for
UpdateIncomeRequest. Decode as agoogle.protobuf.DescriptorProto.final - weekdayDescriptor → Uint8List
-
Descriptor for
Weekday. Decode as agoogle.protobuf.EnumDescriptorProto.final - withdrawFromExpenseReplyDescriptor → Uint8List
-
Descriptor for
WithdrawFromExpenseReply. Decode as agoogle.protobuf.DescriptorProto.final - withdrawFromExpenseRequestDescriptor → Uint8List
-
Descriptor for
WithdrawFromExpenseRequest. Decode as agoogle.protobuf.DescriptorProto.final